Get DataPackageR Project Root Path
Details
Returns the path to the data package project root, or constructs a path to a file in the project root from the file argument.
Examples
if(rmarkdown::pandoc_available()){
project_path( file = "DESCRIPTION" )
}
#> [1] "/tmp/RtmpC7krQW/file5c94dc1da5e/DESCRIPTION"